package no.ntnu.vegare.visualizer.client;

import no.ntnu.vegare.visualizer.client.auth.AuthController;
import no.ntnu.vegare.visualizer.client.connection.HttpsConnection;
import no.ntnu.vegare.visualizer.client.connection.ServerPollDaemon;
import no.ntnu.vegare.visualizer.client.db.AbstractLogDatabase;
import no.ntnu.vegare.visualizer.client.db.SQLiteDatabase;
import no.ntnu.vegare.visualizer.client.main.MainController;
import no.ntnu.vegare.visualizer.client.prototype.DataGenerator;

/**
 * <p>Launch point of the visualization client.</p>
 * 
 * <p>Walks through a four step initialization process:</p>
 * 
 * <ul>
 *  <li>Generates a simulated backlog of data through <code>DataGenerator
 *  </code>, in order to avoid a delay to test the history function of the
 *  prototype. This should be removed in a production system.</li>
 *  <li>Establishes an authenticated connection to the server, through the
 *  <code>AuthController</code> interface.</li>
 *  <li>Launches a <code>ServerPollDaemon</code> to request new log events
 *  from the server at a specified time interval.</li>
 *  <li>Launches the main frame displaying the content of the database.</li>
 * </ul>
 * 
 * @author vegare
 *
 */
public class VisClient {

	public static void main(String[] args) {
		
		HttpsConnection conn = new HttpsConnection();
		AbstractLogDatabase db = new SQLiteDatabase();
		
		DataGenerator.createBacklog(db);
		
		AuthController auth = new AuthController(conn);
		auth.establishConnection();
		
		Thread th = new Thread(new ServerPollDaemon(conn, db));
		th.setDaemon(true);
		th.start();
		
		MainController main = new MainController(db);
		main.launchGui();
	}
}