package no.ntnu.vegare.visualizer.client.auth;

import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPasswordField;
import javax.swing.JTextField;

import no.ntnu.vegare.visualizer.client.connection.HttpsConnection;
import no.ntnu.vegare.visualizer.client.utils.Resources;

/**
 * <p>Displays the connection type, and prompts the user their credentials.
 * Attempts to verify that credentials are ok and server is valid.</p>
 * 
 * @author vegare
 *
 */
public class AuthFrame extends JFrame {

	private static final long serialVersionUID = 1780405703768441717L;
	
	private HttpsConnection model;
	
	private CertificatePanel certPanel;
	private JLabel usernameLbl;
	private JTextField usernameTxt;
	private JLabel passwordLbl;
	private JPasswordField passwordTxt;
	private JLabel errorLbl;
	private JButton loginBtn;
	
	public AuthFrame(HttpsConnection model) {
		
		this.model = model;
		
		initializeComponents();
	}

	private void initializeComponents() {
		
		setTitle("Authentication");
		setSize(400, 400);
		setResizable(false);
		setLayout(null);
		setLocationRelativeTo(null);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		certPanel = new CertificatePanel(model.getConnectionType(),
										 model.getCertificate());
		certPanel.setLocation(0, 0);
		certPanel.setSize(400, 180);
		
		usernameLbl = new JLabel("Username:");
		usernameLbl.setLocation(25, 190);
		usernameLbl.setSize(350, 30);
		
		usernameTxt = new JTextField();
		usernameTxt.setLocation(25, 220);
		usernameTxt.setSize(350, 30);
		usernameTxt.setActionCommand("login");
		
		passwordLbl = new JLabel("Password");
		passwordLbl.setLocation(25, 250);
		passwordLbl.setSize(350, 30);
		
		passwordTxt = new JPasswordField();
		passwordTxt.setLocation(25, 280);
		passwordTxt.setSize(350, 30);
		passwordTxt.setActionCommand("login");
		
		errorLbl = new JLabel("");
		errorLbl.setLocation(30, 320);
		errorLbl.setSize(200, 30);
		
		loginBtn = new JButton("Login");
		loginBtn.setIcon(Resources.getInstance().getImage("connect.png"));
		loginBtn.setLocation(225, 320);
		loginBtn.setSize(150, 35);
		loginBtn.setActionCommand("login");
		
		add(certPanel);
		add(usernameLbl);
		add(usernameTxt);
		add(passwordLbl);
		add(passwordTxt);
		add(errorLbl);
		add(loginBtn);
	}

	public void addActionListener(ActionListener actionListener) {
		usernameTxt.addActionListener(actionListener);
		passwordTxt.addActionListener(actionListener);
		loginBtn.addActionListener(actionListener);
	}
	
	public void displayError(String errorMsg) {
		errorLbl.setIcon(Resources.getInstance().getImage("error.png"));
		errorLbl.setText(errorMsg);
	}

	public String getUsername() {
		return usernameTxt.getText();
	}
	
	public String getPassword() {
		return new String(passwordTxt.getPassword());
	}
}
