package no.ntnu.vegare.visualizer.client.auth;

import java.awt.Color;
import java.awt.Graphics;
import java.security.cert.X509Certificate;

import javax.security.auth.x500.X500Principal;
import javax.swing.JPanel;

import no.ntnu.vegare.visualizer.client.connection.ConnectionType;
import no.ntnu.vegare.visualizer.client.utils.Resources;

/**
 * <p>Draw an infographics explaining whether the given URL provides an:</p>
 * 
 * <ul>
 *  <li>Unencrypted HTTP connection</li>
 *  <li>Unverified HTTPS connection</li>
 *  <li>Verified HTTPS connection</li>
 * </ul>
 * 
 * @author vegare
 *
 */
public class CertificatePanel extends JPanel {

	private static final long serialVersionUID = 6027505142063037896L;
	
	private ConnectionType connectionType;
	private X509Certificate certificate;
	
	public CertificatePanel(ConnectionType type, X509Certificate certificate) {
		this.connectionType = type;
		this.certificate = certificate;
	}

	@Override
	protected void paintComponent(Graphics g) {
		super.paintComponent(g);
		
		switch (connectionType) {
		case HTTP_CONNECTION: 	
			g.drawImage(Resources.getInstance().getImage("httpConnection.png").getImage(),
					0, 0, null);		
			break;
		case HTTPS_UNTRUSTED:	
			g.drawImage(Resources.getInstance().getImage("httpsUntrusted.png").getImage(),
					0, 0, null);					
			break;
		case HTTPS_TRUSTED:		
			g.drawImage(Resources.getInstance().getImage("httpsTrusted.png").getImage(),
					0, 0, null);	
			
			g.setColor(Color.WHITE);
			g.drawString(getX509Field(certificate.getSubjectX500Principal(), "O="), 120, 93);
			g.drawString(getX509Field(certificate.getIssuerX500Principal(), "CN="), 120, 139);
			break;
		}
	}
	
	private String getX509Field(X500Principal principal, String fieldName) {
		
		String name = principal.getName();
		int start = name.indexOf(fieldName) + fieldName.length();
		int end   = name.indexOf(",", start);
		
		String field = name.substring(start, end);
		
		if ("".equals(field))
			return "Unknown";
		
		return field;		
	}
}
