package no.ntnu.vegare.visualizer.client.auth;

import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;

import no.ntnu.vegare.visualizer.client.config.Configuration;
import no.ntnu.vegare.visualizer.client.connection.HttpsConnection;
import no.ntnu.vegare.visualizer.client.utils.Resources;

/**
 * Asks the user for a URL to the server.
 * First screen displayed by the application.
 * 
 * @author vegare
 */
public class UrlFrame extends JFrame {

	private static final long serialVersionUID = 1565456707282015832L;
		
	private JLabel headerImg;
	private JLabel urlLbl;
	private JTextField urlTxt;
	private JLabel errorLbl;
	private JButton connectBtn;
	
	public UrlFrame(HttpsConnection model) {
		
		initializeComponents();
	}

	private void initializeComponents() {
		
		setTitle("Connect to server");
		setSize(400, 400);
		setResizable(false);
		setLayout(null);
		setLocationRelativeTo(null);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		headerImg = new JLabel(Resources.getInstance().getImage("header.png"));
		headerImg.setLocation(0, 0);
		headerImg.setSize(400, 200);
		
		urlLbl = new JLabel("URL:");
		urlLbl.setLocation(25, 240);
		urlLbl.setSize(350, 30);
		
		urlTxt = new JTextField();
		urlTxt.setText(Configuration.getInstance().getDefaultUrl());
		urlTxt.setLocation(25, 270);
		urlTxt.setSize(350, 30);
		urlTxt.setActionCommand("connect");
		
		errorLbl = new JLabel("");
		errorLbl.setLocation(30, 310);
		errorLbl.setSize(200, 30);
		
		connectBtn = new JButton("Connect");
		connectBtn.setIcon(Resources.getInstance().getImage("connect.png"));
		connectBtn.setLocation(225, 310);
		connectBtn.setSize(150, 35);
		connectBtn.setActionCommand("connect");
				
		add(headerImg);
		add(urlLbl);
		add(urlTxt);
		add(errorLbl);
		add(connectBtn);
	}

	public void addActionListener(ActionListener actionListener) {
		urlTxt.addActionListener(actionListener);
		connectBtn.addActionListener(actionListener);
	}
	
	public void displayError(String errorMsg) {
		errorLbl.setIcon(Resources.getInstance().getImage("error.png"));
		errorLbl.setText(errorMsg);
	}

	public String getUrl() {
		return urlTxt.getText();
	}
}