package no.ntnu.vegare.visualizer.client.config;

/**
 * <p>Thread safe singleton implementation by Bill Pugh:
 * <a href="http://en.wikipedia.org/wiki/Singleton_pattern">
 * http://en.wikipedia.org/wiki/Singleton_pattern</a></p>
 * 
 * <p>Provides access to the configuration parameters of the application.
 * These can be modified directly in this class or through the GUI.</p>
 * 
 * @author vegare
 *
 */
public class Configuration {

	private boolean httpAllowed;
	private boolean unverifiedHttpsAllowed;
	private String defaultUrl;
	
	// How many seconds of backlog to fetch
	// when first launching the application
	private int backlogSize;
	
	// How many seconds to sleep between each
	// server request
	private int sleepTime;
	
	// Private constructor prevents instantiation from other classes
	private Configuration() {
		
		setHttpAllowed(true);
		setUnverifiedHttpsAllowed(true);
		setDefaultUrl("http://localhost:8080/");
		
		setBacklogSize(5*60*1000);
		setSleepTime(1*10*1000);
	}
	 
	/**
	 * SingletonHolder is loaded on the first execution of Singleton.getInstance() 
	 * or the first access to SingletonHolder.INSTANCE, not before.
	 */
	private static class SingletonHolder { 
		public static final Configuration INSTANCE = new Configuration();
	}
	 
	public static Configuration getInstance() {
		return SingletonHolder.INSTANCE;
	}

	public boolean isHttpAllowed() {
		return httpAllowed;
	}

	public void setHttpAllowed(boolean httpAllowed) {
		this.httpAllowed = httpAllowed;
	}
	
	public boolean isUnverifiedHttpsAllowed() {
		return unverifiedHttpsAllowed;
	}

	public void setUnverifiedHttpsAllowed(boolean unverifiedHttpsAllowed) {
		this.unverifiedHttpsAllowed = unverifiedHttpsAllowed;
	}

	public String getDefaultUrl() {
		return defaultUrl;
	}
	
	public void setDefaultUrl(String url) {
		defaultUrl = url;
	}

	public int getBacklogSize() {
		return backlogSize;
	}

	public void setBacklogSize(int backlogSize) {
		this.backlogSize = backlogSize;
	}

	public void setSleepTime(int sleepTime) {
		this.sleepTime = sleepTime;
	}

	public int getSleepTime() {
		return sleepTime;
	}
}
