package no.ntnu.vegare.visualizer.client.connection;

import java.net.MalformedURLException;
import java.net.URL;
import java.security.cert.X509Certificate;

/**
 * <p>A model representing a single HTTP or HTTPS connection.</p>
 * 
 * @author vegare
 *
 */
public class HttpsConnection {

	private String url;
	private String username;
	private String password;
	
	private ConnectionType connectionType;
	private X509Certificate certificate;
	
	public HttpsConnection() {}
	
	/**
	 * <p>Attempt to set the URL and connection type used for this connection.</p>
	 * 
	 * @throws MalformedURLException Invalid URL or invalid protocol
	 */
	public void setUrl(String url) throws MalformedURLException {
		
		// Protocol check
		if (url.startsWith("https"))
			setConnectionType(ConnectionType.HTTPS_UNTRUSTED);
		else if (url.startsWith("http"))
			setConnectionType(ConnectionType.HTTP_CONNECTION);
		else
			throw new MalformedURLException();
		
		// Validate
		try {
			new URL(url);
		} catch (MalformedURLException e) {
			throw e;
		}
		
		this.url = url;
	}

	public String getUrl() {
		return url;
	}

	public void setUsername(String username) {
		this.username = username;
	}
	
	public String getUsername() {
		return username;
	}

	public void setPassword(String password) {
		this.password = password;
	}
	
	public String getPassword() {
		return password;
	}

	public void setConnectionType(ConnectionType connectionType) {
		this.connectionType = connectionType;
	}

	public ConnectionType getConnectionType() {
		return connectionType;
	}

	public void setCertificate(X509Certificate certificate) {
		this.certificate = certificate;
		
		if (certificate != null) {
			setConnectionType(ConnectionType.HTTPS_TRUSTED);
		}
	}

	public X509Certificate getCertificate() {
		return certificate;
	}
}
