package no.ntnu.vegare.visualizer.client.connection;

import java.util.HashMap;
import java.util.Map;

import biz.source_code.base64Coder.Base64Coder;

/**
 * <p>Model holding data of a single HTTPS request.</p>
 * 
 * @author vegare
 *
 */
public class HttpsRequest {

	private String rootUrl;
	
	private String authorization;
	private HashMap<String, String> params;
	
	public HttpsRequest(String rootUrl)
	{
		this.rootUrl = rootUrl;
		params = new HashMap<String, String>(3);
	}

	/**
	 * Constructs URL based on root and query string parameters
	 */
	public String getUrl() {
		
		StringBuilder url = new StringBuilder();
		
		url.append(rootUrl);
		
		if (params.size() > 0) {
			url.append("?");
			for (Map.Entry<String, String> entry : params.entrySet()) {
			    String key = entry.getKey();
			    String value = entry.getValue();
			    
			    url.append(key);
			    url.append("=");
			    url.append(value);
			    url.append("&");
			}
			url.deleteCharAt(url.length()-1);	
		}
		
		return url.toString();
	}

	/**
	 * <p>Add a query string parameter to the URL, on the form
	 * <code>key=value</code></p>
	 * 
	 * @param key Query string key
	 * @param value Query string value
	 */
	public void addParameter(String key, String value) {
		params.put(key, value);
	}
	
	/**
	 * Add an authentication string to the HTTP request.
	 * 
	 * @param authType Authentication type, usually basic
	 * @param username Username
	 * @param password Password
	 */
	public void setAuthorization(String authType, String username, String password) {
		authorization = authType + " " + Base64Coder.encodeString(username + ":" + password);
	}
	
	public String getAuthorization() {
		return authorization;
	}
}
