package no.ntnu.vegare.visualizer.client.db;

import java.util.ArrayList;
import java.util.Collection;

/**
 * <p>Abstract interface for a database. Implements the observer pattern, and
 * dictates query methods required by each specific implementation.</p>
 * 
 * @author vegare
 *
 */
public abstract class AbstractLogDatabase {

	private Collection<DatabaseObserver> observerList;
	
	public abstract void addEntries(Collection<LogEntry> entries);
	public abstract ArrayList<LogEntry> getAll();
	public abstract ArrayList<LogEntry> query(QueryFilter filter);

	public AbstractLogDatabase() {
		observerList = new ArrayList<DatabaseObserver>(3);
	}
	
	public void addDatabaseObserver(DatabaseObserver o) {
		observerList.add(o);
	}
	
	public void removeDatabaseObserver(DatabaseObserver o) {
		observerList.remove(o);
	}
	
	public void fireEntriesAdded(final Collection<LogEntry> entryList) {
		
		for (DatabaseObserver o : observerList)
			o.entriesAdded(entryList);
	}
}
