package no.ntnu.vegare.visualizer.client.db;

/**
 * <p>Specifies a set of filters to be applied to the log database.</p>
 * 
 * <p>Can be used to create a live filtering of log entries that belongs to a
 * log entry set.</p>
 * 
 * @see LogEntrySet
 * @author vegare
 *
 */
public class QueryFilter {

	private int minTimestamp;
	private int maxTimestamp;
	private int minSeverity;
	private String facility;
	private String ipPrefix;
	private String messageContains;
	
	public QueryFilter() {
		clear();	
	}

	/**
	 * Clear the query filter to default, capturing all incidents.
	 */
	public void clear() {
		minTimestamp = Integer.MIN_VALUE;
		maxTimestamp = Integer.MAX_VALUE;
		minSeverity = 7;
		facility = "";
		ipPrefix = "";
		messageContains = "";	
	}
	
	/**
	 * Verify if a single entry matches the filter.
	 * 
	 * @param e Log entry
	 * @return Whether the filter includes the entry
	 */
	public boolean matches(LogEntry e) {
		
		return minTimestamp <= e.getTimestamp()
			&& maxTimestamp >= e.getTimestamp()
			&& minSeverity >= e.getSeverity()
			&& e.getIpaddress().startsWith(ipPrefix)
			&& e.getFacility().contains(facility)
			&& e.getMessage().contains(messageContains);
	}
	
	public int getMinTimestamp() {
		return minTimestamp;
	}

	public void setMinTimestamp(int minTimestamp) {
		this.minTimestamp = minTimestamp;
	}

	public int getMaxTimestamp() {
		return maxTimestamp;
	}

	public void setMaxTimestamp(int maxTimestamp) {
		this.maxTimestamp = maxTimestamp;
	}

	public String getFacility() {
		return facility;
	}

	public void setFacility(String facility) {
		this.facility = facility;
	}

	public int getMinPriority() {
		return minSeverity;
	}

	public void setMinSeverity(int minPriority) {
		this.minSeverity = minPriority;
	}

	public String getIpPrefix() {
		return ipPrefix;
	}

	public void setIpPrefix(String ipPrefix) {
		this.ipPrefix = ipPrefix;
	}

	public String getMessageContains() {
		return messageContains;
	}

	public void setMessageContains(String messageContains) {
		this.messageContains = messageContains;
	}
}
