package no.ntnu.vegare.visualizer.client.main.details;

import java.awt.BorderLayout;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JPanel;
import javax.swing.event.ListDataEvent;
import javax.swing.event.ListDataListener;

import no.ntnu.vegare.visualizer.client.utils.Resources;

/**
 * <p>Panel displaying a log report and a navigation toolbar to move through
 * the history of previously viewed reports. Follows browser patterns.</p>
 * 
 * @author vegare
 *
 */
public class DetailPanel extends JPanel implements ListDataListener {

	private static final long serialVersionUID = -1286676501109975327L;

	private static final String[] EMPTY_MSG = new String[] {
			"No reports have been generated.",
			"Please select an event from the filter view." };

	private LogReportSet model;
	
	private JPanel toolBar;
	private JButton previousBtn;
	private JButton nextBtn;
	private JButton reloadBtn;
	private JButton homeBtn;
	private JComboBox historyList;
	private ReportPanel reportPanel;
	
	public DetailPanel(LogReportSet model) {
		
		this.model = model;
		this.model.addListDataListener(this);
		
		setName("Report");
		
		initComponents();
	}

	private void initComponents() {

		this.setLayout(new BorderLayout());

		// Add toolbar
		toolBar = new JPanel();
		previousBtn = new JButton(Resources.getInstance().getImage("previous.png"));
		previousBtn.setActionCommand("previous");
		previousBtn.setPreferredSize(new Dimension(30, 30));
		previousBtn.setEnabled(false);
		
		nextBtn = new JButton(Resources.getInstance().getImage("next.png"));
		nextBtn.setActionCommand("next");
		nextBtn.setPreferredSize(new Dimension(30, 30));
		nextBtn.setEnabled(false);
		
		reloadBtn = new JButton(Resources.getInstance().getImage("refresh.png"));
		reloadBtn.setActionCommand("reload");
		reloadBtn.setPreferredSize(new Dimension(30, 30));
		
		homeBtn = new JButton(Resources.getInstance().getImage("home.png"));
		homeBtn.setActionCommand("home");
		homeBtn.setPreferredSize(new Dimension(30, 30));
		
		historyList = new JComboBox(model);
		historyList.setActionCommand("history");
		historyList.setPreferredSize(new Dimension(850, 30));
		
		toolBar.add(previousBtn);
		toolBar.add(nextBtn);
		toolBar.add(reloadBtn);
		toolBar.add(homeBtn);
		toolBar.add(historyList);

		this.add(toolBar, BorderLayout.NORTH);

		// Add report
		reportPanel = new ReportPanel();

		this.add(reportPanel, BorderLayout.CENTER);
	}
	
	public void addActionListener(ActionListener l) {
		
		previousBtn.addActionListener(l);
		nextBtn.addActionListener(l);
		reloadBtn.addActionListener(l);
		homeBtn.addActionListener(l);
		historyList.addActionListener(l);
	}

	public int getSelectedIndex() {
		return historyList.getSelectedIndex();
	}

	public void toggleButton(String button, boolean enabled) {
		
		if ("previous".equals(button))
			previousBtn.setEnabled(enabled);
		else if ("next".equals(button))
			nextBtn.setEnabled(enabled);
		else if ("reload".equals(button))
			reloadBtn.setEnabled(enabled);
		else if ("home".equals(button))
			homeBtn.setEnabled(enabled);
	}
	
	private void dataChanged() {
		
		reportPanel.updateView(model.getCurrentEntry());
		
		if (model.isFirst())	toggleButton("previous", false);
		else					toggleButton("previous", true);

		if (model.isLast())		toggleButton("next", false);
		else					toggleButton("next", true);
	}
	
	@Override
	public void paint(Graphics g) {

		// Draw an overlay if no reports have been generated,
		// otherwise go on and draw the panel as usual.
		if (model.isEmpty()) {
			g.setColor(getBackground());
			g.fillRect(0, 0, getWidth(), getHeight());
			g.setColor(Color.BLACK);

			int y = (getHeight() / 2) - 60;
			for (String str : EMPTY_MSG) {
				g.drawString(str, (getWidth() / 2)
						- (g.getFontMetrics().stringWidth(str) / 2), y);
				y += 20;
			}
		} else {
			super.paint(g);
		}
	}
	
	@Override
	public void intervalAdded(ListDataEvent e) {
		dataChanged();
	}

	@Override
	public void intervalRemoved(ListDataEvent e) {
		dataChanged();
	}

	@Override
	public void contentsChanged(ListDataEvent e) {
		dataChanged();
	}

	public void updateReportPanel() {
		dataChanged();
	}
}
