package no.ntnu.vegare.visualizer.client.main.details;

import no.ntnu.vegare.visualizer.client.db.AbstractLogDatabase;
import no.ntnu.vegare.visualizer.client.db.LogEntry;
import no.ntnu.vegare.visualizer.client.utils.TimeUtils;

/**
 * <p>A model for the detail panel. Contains a log entry and relevant
 * additional data. In the prototype, it only holds an entry.</p>
 * 
 * <p>Currently only holding a report, but in the future it should also
 * include information from third parties, or additional data extracted
 * from the database.</p>
 * 
 * <p>Is static, once generated it should not add any overhead when displayed
 * or refreshed in the report view.</p>
 * 
 * @author vegare
 *
 */
public class LogReport {

	private String[] severityStr = new String[]{"Emergency","Alert",
											    "Critical", "Error",
											    "Warning", "Notice",
											    "Debug", "Info"};
	
	private LogEntry entry;
	
	public LogReport(AbstractLogDatabase db, LogEntry entry) {
		
		this.entry = entry;		
		generateReport();
	}

	private void generateReport() {
		
		// TODO: Generate report
		//		 Fetch time/space locality incidents
		//		 and similar activities
	}

	public void reload() {
		generateReport();
	}
	
	public LogEntry getEntry() {
		return entry;
	}
	
	public String toString() {
		
		return entry.getId()
			 + " - "
			 + severityStr[entry.getSeverity()]
			 + " incident in '"
			 + entry.getFacility()
			 + "' from '"
			 + entry.getIpaddress()
			 + "' at '"
			 + TimeUtils.timestampToDate(entry.getTimestamp())
			 + "'";
	}
}
