package no.ntnu.vegare.visualizer.client.main.details;

import java.util.ArrayList;

import javax.swing.AbstractListModel;
import javax.swing.ComboBoxModel;

/**
 * <p>Contains a history of viewed log reports. Serves both as a cache of
 * database data and a model for the JComboBox allowing navigation between 
 * reports.</p>
 * 
 * @author vegare
 *
 */
public class LogReportSet extends AbstractListModel implements ComboBoxModel {

	private static final long serialVersionUID = -7145489371467015172L;

	private static final int MAX_SIZE = 20;
	
	private ArrayList<LogReport> history;
	private LogReport currentReport;

	public LogReportSet() {
		history = new ArrayList<LogReport>(MAX_SIZE);
	}

	/**
	 * Called when a new log report is selected from the filter view.
	 * This is the only way to generate a new detailed log report.
	 */
	public void addEntry(LogReport entry) {

		if (history.size() >= MAX_SIZE) {
			history.remove(0);
			fireIntervalRemoved(this, 0, 0);
		}
		
		if (history.contains(entry)) {
			switchEntry(history.lastIndexOf(currentReport));
		}
		
		history.add(entry);
		currentReport = entry;
		fireIntervalAdded(this, history.lastIndexOf(currentReport), history.lastIndexOf(currentReport));		
	}

	public boolean isEmpty() {
		return history.size() == 0;
	}

	public boolean isFirst() {
		return history.lastIndexOf(currentReport) == 0;
	}
	
	public boolean isLast() {
		return history.lastIndexOf(currentReport) == history.size()-1;
	}
	
	public LogReport getCurrentEntry() {
		return currentReport;
	}
	
	public void nextEntry() {

		int currentIndex = history.lastIndexOf(currentReport);
		if (currentIndex < history.size()-1) {
			switchEntry(currentIndex + 1);
		}
	}

	public void prevEntry() {

		int currentIndex = history.lastIndexOf(currentReport);
		if (currentIndex > 0) {
			switchEntry(currentIndex - 1);
		}
	}

	public void lastEntry() {
		
		if (history.size() > 0)
			switchEntry(history.size()-1);
	}

	public void switchEntry(int index) {

		if (index >= 0 && index <= MAX_SIZE) {
			currentReport = history.get(index);
			fireContentsChanged(this, 0, history.size());
		}
	}

	public void reloadCurrent() {
		currentReport.reload();
	}

	@Override
	public int getSize() {
		return history.size();
	}

	@Override
	public Object getElementAt(int index) {
		return history.get(index);
	}

	@Override
	public void setSelectedItem(Object anItem) {
		currentReport = (LogReport) anItem;
	}

	@Override
	public Object getSelectedItem() {
		return currentReport;
	}
}
