package no.ntnu.vegare.visualizer.client.main.details;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Insets;

import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;

import no.ntnu.vegare.visualizer.client.db.LogEntry;
import no.ntnu.vegare.visualizer.client.utils.TimeUtils;

/**
 * <p>A specialized panel dedicated to drawing a pre-generated log report.</p>
 * 
 * @author vegare
 *
 */
public class ReportPanel extends JPanel {

	private static final long serialVersionUID = 5600630990036736120L;

	private String[] severityStr = new String[]{"Emergency","Alert",
											    "Critical", "Error",
											    "Warning", "Notice",
											    "Debug", "Info"};
	
	private final Dimension panelSize = new Dimension(300, 380);
	private final Dimension labelSize = new Dimension(250, 30);
	private final Dimension componentSize = new Dimension(250, 30);
	
	private JLabel idLbl;
	private JTextField id;
	private JLabel severityLbl;
	private JTextField severity;
	private JLabel facilityLbl;
	private JTextField facility;
	private JLabel ipAddressLbl;
	private JTextField ipAddress;
	private JLabel locationLbl;
	private JTextField location;
	private JLabel datetimeLbl;
	private JTextField datetime;
	
	private JLabel msgLbl;
	private JScrollPane msgScroll;
	private JTextArea message;
	
	private JLabel spaceLbl;
	private JScrollPane spaceScroll;
	private JTextArea space;
	private JLabel timeLbl;
	private JScrollPane timeScroll;
	private JTextArea time;
	
	private JLabel rawLbl;
	private JScrollPane rawScroll;
	private JTextArea raw;
	
	public ReportPanel() {
		
		initializeComponents();
	}
	
	private void initializeComponents() {
		
		idLbl = new JLabel("ID:");
		idLbl.setPreferredSize(labelSize);
		
		id = new JTextField();
		id.setPreferredSize(componentSize);
		id.setEditable(false);
		
		severityLbl = new JLabel("Severity:");
		severityLbl.setPreferredSize(labelSize);
		
		severity = new JTextField();
		severity.setPreferredSize(componentSize);
		severity.setEditable(false);
		
		facilityLbl = new JLabel("Facility:");
		facilityLbl.setPreferredSize(labelSize);
		
		facility = new JTextField("");
		facility.setPreferredSize(componentSize);
		facility.setEditable(false);
		
		ipAddressLbl = new JLabel("Source IP address:");
		ipAddressLbl.setPreferredSize(labelSize);
		
		ipAddress = new JTextField("");
		ipAddress.setPreferredSize(componentSize);
		ipAddress.setEditable(false);

		locationLbl = new JLabel("Location:");
		locationLbl.setPreferredSize(labelSize);
		
		location = new JTextField("");
		location.setPreferredSize(componentSize);
		location.setEditable(false);
		
		datetimeLbl = new JLabel("Time of occurence:");
		datetimeLbl.setPreferredSize(labelSize);
		
		datetime = new JTextField("");
		datetime.setPreferredSize(componentSize);
		datetime.setEditable(false);
		
		msgLbl = new JLabel("Message:");
		msgLbl.setPreferredSize(labelSize);
		
		message = new JTextArea();
		message.setEditable(false);
		message.setMargin(new Insets(5,5,5,5)); 
		message.setLineWrap(true);
		message.setWrapStyleWord(true);
		
		msgScroll = new JScrollPane(message);
		msgScroll.setPreferredSize(new Dimension(250, 330));
		
		spaceLbl = new JLabel("User incidents:");
		spaceLbl.setPreferredSize(labelSize);
		
		space = new JTextArea();
		space.setEditable(false);
		space.setMargin(new Insets(5,5,5,5));
		space.setText("Clickable list of incidents from the same user, in this or other logs");
		space.setLineWrap(true);
		space.setWrapStyleWord(true);
		
		spaceScroll = new JScrollPane(space);
		spaceScroll.setPreferredSize(new Dimension(250, 150));
		
		timeLbl = new JLabel("Close in time:");
		timeLbl.setPreferredSize(labelSize);
		
		time = new JTextArea();
		time.setEditable(false);
		time.setMargin(new Insets(5,5,5,5)); 
		time.setText("Clickable list of incidents immediately before and after this incident, in this or other logs");
		time.setLineWrap(true);
		time.setWrapStyleWord(true);
		
		timeScroll = new JScrollPane(time);
		timeScroll.setPreferredSize(new Dimension(250, 150));
		
		rawLbl = new JLabel("Raw log:");
		rawLbl.setPreferredSize(new Dimension(850, 30));
		
		raw = new JTextArea();
		raw.setEditable(false);
		raw.setMargin(new Insets(5,5,5,5)); 
		raw.setText("In the real system, this box will contain an excerpt from the raw log file");
		raw.setLineWrap(true);
		raw.setWrapStyleWord(true);
		
		rawScroll = new JScrollPane(raw);
		rawScroll.setPreferredSize(new Dimension(850, 180));
		
		JPanel leftPanel = new JPanel();
		leftPanel.setPreferredSize(panelSize);
		leftPanel.setLayout(new FlowLayout(FlowLayout.CENTER, 5, 0));
		
		JPanel centerPanel = new JPanel();
		centerPanel.setPreferredSize(panelSize);
		centerPanel.setLayout(new FlowLayout(FlowLayout.CENTER, 5, 0));
		
		JPanel rightPanel = new JPanel();
		rightPanel.setPreferredSize(panelSize);
		rightPanel.setLayout(new FlowLayout(FlowLayout.CENTER, 5, 0));
		
		JPanel bottomPanel = new JPanel();
		bottomPanel.setPreferredSize(new Dimension(850, 250));
		bottomPanel.setLayout(new FlowLayout(FlowLayout.CENTER, 5, 0));
		
		leftPanel.add(idLbl);
		leftPanel.add(id);
		leftPanel.add(severityLbl);
		leftPanel.add(severity);
		leftPanel.add(facilityLbl);
		leftPanel.add(facility);
		leftPanel.add(ipAddressLbl);
		leftPanel.add(ipAddress);
		leftPanel.add(locationLbl);
		leftPanel.add(location);
		leftPanel.add(datetimeLbl);
		leftPanel.add(datetime);
		centerPanel.add(msgLbl);
		centerPanel.add(msgScroll);
		rightPanel.add(spaceLbl);
		rightPanel.add(spaceScroll);
		rightPanel.add(timeLbl);
		rightPanel.add(timeScroll);
		bottomPanel.add(rawLbl);
		bottomPanel.add(rawScroll);
		
		add(leftPanel);
		add(centerPanel);
		add(rightPanel);
		add(bottomPanel);
	}

	public void updateView(LogReport currentEntry) {
		
		LogEntry e = currentEntry.getEntry();
		
		id.setText(e.getId() + "");
		facility.setText(e.getFacility());
		severity.setText(severityStr[e.getSeverity()]);
		ipAddress.setText(e.getIpaddress());
		location.setText(e.getLocationString());
		datetime.setText(TimeUtils.timestampToDate(e.getTimestamp()));
		message.setText(e.getMessage());
	}
}
