package no.ntnu.vegare.visualizer.client.main.filter;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.event.EventListenerList;

import no.ntnu.vegare.visualizer.client.db.LogEntrySet;
import no.ntnu.vegare.visualizer.client.db.QueryFilter;
import no.ntnu.vegare.visualizer.client.utils.TimeUtils;

/**
 * <p>Panel for searching and listing log events matching a specific criteria.
 * Sends action events back to any listener once a specific log event has been
 * selected, otherwise self contained.</p>
 * 
 * @author vegare
 *
 */
public class FilterPanel extends JPanel implements MouseListener {

	private static final long serialVersionUID = 1858647521420608935L;

	private EventListenerList listenerList = new EventListenerList();

	private LogEntrySet model;

	private JScrollPane scrollPane;
	private SearchPanel searchPanel;
	private JTable searchResults;
	
	public FilterPanel(LogEntrySet model) {
		
		this.model = model;
		
		setName("Filter");
		
		initializeComponents();
		
		QueryFilter filter = new QueryFilter();
		filter.setMinTimestamp(TimeUtils.getCurrentTime() - TimeUtils.HOUR);		
		model.setQueryFilter(filter);
	}

	private void initializeComponents() {
		
		setLayout(new BorderLayout());
		
		searchPanel = new SearchPanel();
		searchPanel.setPreferredSize(new Dimension(220, 700));
		
		searchResults = new JTable();
		searchResults.setModel(model);
		searchResults.addMouseListener(this);
		searchResults.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
		searchResults.setAutoCreateRowSorter(true);
		searchResults.setFillsViewportHeight(true);
		
		searchResults.getColumnModel().getColumn(0).setPreferredWidth(4);
		
		scrollPane = new JScrollPane(searchResults);
		
		add(searchPanel, BorderLayout.WEST);
		add(scrollPane, BorderLayout.CENTER);
	}
		
	public void addActionListener(ActionListener l) {
		listenerList.add(ActionListener.class, l);
		searchPanel.addActionListener(l);
	}

	public void clearSearch() {
		searchPanel.clear();
	}

	public QueryFilter getQueryFilter() {
		return searchPanel.getQueryFilter();
	}
	
	/**
	 * Used to send report selections back to MainController
	 */
	private void fireActionPerformed(ActionEvent event) {
		
        Object[] listeners = listenerList.getListenerList();

        for (int i = listeners.length-2; i>=0; i-=2) {
            if (listeners[i]==ActionListener.class) {
                ((ActionListener)listeners[i+1]).actionPerformed(event);
            }          
        }
	}
	
	@Override
	public void mouseClicked(MouseEvent e) {		
		if (e.getClickCount() == 2) {
			ActionEvent event = new ActionEvent(model.getEntry(searchResults.getSelectedRow()), 0, "filter");
			fireActionPerformed(event);
		}
	}

	@Override
	public void mousePressed(MouseEvent e) {}

	@Override
	public void mouseReleased(MouseEvent e) {}

	@Override
	public void mouseEntered(MouseEvent e) {}

	@Override
	public void mouseExited(MouseEvent e) {}
}
