package no.ntnu.vegare.visualizer.client.main.filter;

import java.awt.Dimension;
import java.awt.event.ActionListener;
import java.util.Date;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.JTextField;
import javax.swing.SpinnerDateModel;

import no.ntnu.vegare.visualizer.client.db.QueryFilter;
import no.ntnu.vegare.visualizer.client.utils.Resources;
import no.ntnu.vegare.visualizer.client.utils.TimeUtils;

/**
 * <p>Fill out a <code>QueryFilter</code> to filter log entries.</p>
 * 
 * @see QueryFilter
 * @author vegare
 *
 */
public class SearchPanel extends JPanel {
	
	static final long serialVersionUID = -6355903646385926821L;
		
	private final Dimension labelSize = new Dimension(190, 20);
	private final Dimension boxSize = new Dimension(200, 25);
	private final Dimension buttonSize = new Dimension(100, 30);
	
	private JLabel ipLbl;
	private JTextField ipTxt;
	private JLabel priorityLbl;
	private JComboBox severityBox;
	private JLabel facilityLbl;
	private JTextField facilityTxt;
	private JLabel minTimeLbl;
	private JSpinner minTimeTxt;
	private JLabel maxTimeLbl;
	private JSpinner maxTimeTxt;
	private JLabel messageLbl;
	private JTextField messageTxt;
	
	private JButton clear;
	private JButton search;
	
	public SearchPanel() {
	
		initializeComponents();
	}
	
	private void initializeComponents() {

		ipLbl = new JLabel("IP address (prefix):");
		ipLbl.setPreferredSize(labelSize);
		ipTxt = new JTextField();
		ipTxt.setPreferredSize(boxSize);
			
		priorityLbl = new JLabel("Minimum priority:");
		priorityLbl.setPreferredSize(labelSize);
		severityBox = new JComboBox(new String[]{"Emergency","Alert",
												 "Critical", "Error",
												 "Warning", "Notice",
												 "Debug", "Info"});
		
		severityBox.setPreferredSize(boxSize);
		severityBox.setSelectedIndex(7);
		
		facilityLbl = new JLabel("Facility:");
		facilityLbl.setPreferredSize(labelSize);
		facilityTxt = new JTextField();
		facilityTxt.setPreferredSize(boxSize);
		
		minTimeLbl = new JLabel("Time (from):");
		minTimeLbl.setPreferredSize(labelSize);
		minTimeTxt = new JSpinner(new SpinnerDateModel());
		minTimeTxt.setPreferredSize(boxSize);
		
		maxTimeLbl = new JLabel("Time (to):");
		maxTimeLbl.setPreferredSize(labelSize);
		maxTimeTxt = new JSpinner(new SpinnerDateModel());
		maxTimeTxt.setPreferredSize(boxSize);

		JSpinner.DateEditor minEditor = new JSpinner.DateEditor(minTimeTxt, "dd.MM.yyyy HH:mm");
		JSpinner.DateEditor maxEditor = new JSpinner.DateEditor(maxTimeTxt, "dd.MM.yyyy HH:mm");
		
		minTimeTxt.setEditor(minEditor);
		minTimeTxt.setValue(TimeUtils.getCurrentPlus(-TimeUtils.DAY));
		maxTimeTxt.setEditor(maxEditor);
		maxTimeTxt.setValue(TimeUtils.getCurrentPlus(TimeUtils.DAY));
		
		messageLbl = new JLabel("Message:");
		messageLbl.setPreferredSize(labelSize);
		messageTxt = new JTextField();
		messageTxt.setPreferredSize(boxSize);
		
		clear = new JButton("Clear", Resources.getInstance().getImage("clear.png"));
		clear.setPreferredSize(buttonSize);
		clear.setActionCommand("clear");
		
		search = new JButton("Search", Resources.getInstance().getImage("search.png"));
		search.setPreferredSize(buttonSize);
		search.setActionCommand("search");
		
		add(ipLbl);
		add(ipTxt);
		add(priorityLbl);
		add(severityBox);
		add(facilityLbl);
		add(facilityTxt);
		add(minTimeLbl);
		add(minTimeTxt);
		add(maxTimeLbl);
		add(maxTimeTxt);
		add(messageLbl);
		add(messageTxt);
		add(clear);
		add(search);
	}
	
	public void clear() {
		
		ipTxt.setText("");
		severityBox.setSelectedIndex(7);
		facilityTxt.setText("");
		minTimeTxt.setValue(TimeUtils.getCurrentPlus(-TimeUtils.DAY));
		maxTimeTxt.setValue(TimeUtils.getCurrentPlus(TimeUtils.DAY));
		messageTxt.setText("");
	}
	
	public void addActionListener(ActionListener l) {
		
		clear.addActionListener(l);
		search.addActionListener(l);
	}
	
	public QueryFilter getQueryFilter() {
		
		QueryFilter filter = new QueryFilter();
		
		filter.setFacility(facilityTxt.getText());
		filter.setIpPrefix(ipTxt.getText());
		filter.setMinSeverity(severityBox.getSelectedIndex());
		filter.setMinTimestamp(TimeUtils.dateToTimestamp((Date)minTimeTxt.getModel().getValue()));
		filter.setMaxTimestamp(TimeUtils.dateToTimestamp((Date)maxTimeTxt.getModel().getValue()));
		filter.setMessageContains(messageTxt.getText());
		
		return filter;
	}
}
