package no.ntnu.vegare.visualizer.client.main.overview;

import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;

import no.ntnu.vegare.visualizer.client.db.AbstractLogDatabase;
import no.ntnu.vegare.visualizer.client.db.LogEntrySet;
import no.ntnu.vegare.visualizer.client.db.QueryFilter;
import no.ntnu.vegare.visualizer.client.main.overview.history.TimeSeries;
import no.ntnu.vegare.visualizer.client.utils.TimeUtils;

/**
 * <p>Handles interaction internally in the overview panel:</p>
 * 
 * <ul>
 *  <li>Click on the history graph</li>
 *  <li>Click on the live area</li>
 * </ul>
 * 
 * @author vegare
 *
 */
public class OverviewController implements PropertyChangeListener {

	private AbstractLogDatabase db;

	private LogEntrySet logEntrySet;
	private OverviewPanel view;

	public OverviewController(AbstractLogDatabase db, LogEntrySet logEntrySet, TimeSeries timeSeries, OverviewPanel view) {

		this.db = db;
		this.logEntrySet = logEntrySet;
		this.view = view;
		
		view.addPropertyChangeListener(this);
	}

	@Override
	public void propertyChange(PropertyChangeEvent evt) {
		
		if ("time".equals(evt.getPropertyName())) {
			
			int newTime = (Integer) evt.getNewValue();
			
			QueryFilter filter = new QueryFilter();
			filter.setMinTimestamp(newTime - TimeUtils.HOUR);
			filter.setMaxTimestamp(newTime);

			logEntrySet.setCurrentTime(newTime);
			logEntrySet.setEntries(db.query(filter));
			
		} else if ("live".equals(evt.getPropertyName())) {
			
			QueryFilter filter = new QueryFilter();
			filter.setMinTimestamp(TimeUtils.getCurrentTime() - TimeUtils.HOUR);
			
			logEntrySet.setQueryFilter(filter);
		}
		
		view.repaint();
	}
}
