package no.ntnu.vegare.visualizer.client.main.overview.gauge;

import java.awt.Color;
import java.awt.Cursor;
import java.awt.Font;
import java.awt.Graphics;
import java.awt.Image;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.awt.geom.Rectangle2D;

import javax.swing.JPanel;
import javax.swing.event.EventListenerList;

import no.ntnu.vegare.visualizer.client.db.LogEntrySet;
import no.ntnu.vegare.visualizer.client.utils.Resources;

/**
 * <p>Displays a simple gauge, containing the amount of incidents in the map.</p>
 * 
 * @author vegare
 *
 */
public class GaugePanel extends JPanel implements MouseListener {

	private static final long serialVersionUID = 7402902709807526508L;

	private EventListenerList listenerList = new EventListenerList();
	
	private LogEntrySet model;
	
	public GaugePanel(LogEntrySet model) {
		
		this.model = model;
		
		addMouseListener(this);
	}

	@Override
	protected void paintComponent(Graphics g) {
		
		// Draw header
		g.setColor(Color.BLACK);
		g.fillRect(0, 0, getWidth(), 21);
		
		g.setColor(Color.DARK_GRAY);
		g.fillRect(2, 2, getWidth()-4, 17);
		
		g.setColor(Color.WHITE);
		g.drawString("Gauge", 5, 14);

		g.setColor(Color.BLACK);
		g.fillRect(0, 22, getWidth(), getHeight()-26);
		
		// Draw background circle
		Image img;
		
		switch (model.getMaxPriority()) {
		case 0: 
		case 1:  img = Resources.getInstance().getImage("gauge/red.png").getImage();
				 break;
		case 2: 
		case 3:  img = Resources.getInstance().getImage("gauge/yellow.png").getImage();
				 break;
		case 4: 
		case 5:  img = Resources.getInstance().getImage("gauge/green.png").getImage();
				 break;
		case 6: 
		case 7: 
		default: img = Resources.getInstance().getImage("gauge/gray.png").getImage();
				 break;
		}
				
		g.drawImage(img, 0, 20, null);

		// Draw number
		g.setFont(new Font("arial", Font.BOLD, 72));
		
		Rectangle2D rect = g.getFontMetrics().getStringBounds(model.getRowCount() + "", g);
		
		g.drawString(model.getRowCount() + "", (int)((getWidth()/2)-(rect.getWidth()/2)), (int)((getHeight()/2)+34));
	}

	@Override
	public void mouseEntered(MouseEvent e) {
		setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
	}

	@Override
	public void mouseExited(MouseEvent e) {
		setCursor(Cursor.getDefaultCursor());
	}
	
	@Override
	public void mouseClicked(MouseEvent e) {
		ActionEvent evt = new ActionEvent(this, 0, "gauge");
		fireActionPerformed(evt);
	}
	
	public void addActionListener(ActionListener l) {
		listenerList.add(ActionListener.class, l);
	}

	/**
	 * Used to send clicks back to MainController
	 */
	private void fireActionPerformed(ActionEvent event) {
		
        Object[] listeners = listenerList.getListenerList();

        for (int i = listeners.length-2; i>=0; i-=2) {
            if (listeners[i]==ActionListener.class) {
                ((ActionListener)listeners[i+1]).actionPerformed(event);
            }          
        }
	}
	
	@Override
	public void mousePressed(MouseEvent e) {}

	@Override
	public void mouseReleased(MouseEvent e) {}
}