package no.ntnu.vegare.visualizer.client.utils;

import java.io.IOException;
import java.net.InetAddress;

import com.maxmind.geoip.Location;
import com.maxmind.geoip.LookupService;

/**
 * <p>Interface to MaxMind GeoIP (<a href="http://www.maxmind.com/app/java">
 * http://www.maxmind.com/app/java</a>), which is a database of IP address
 * to location relationships.</p>
 * 
 * <p>The file is located in the folder geoip/GeoIPCity.dat, and can be updated
 * from MaxMind's websites when new versions are released.</p>
 * 
 * @author vegare
 *
 */
public class GeoIP {

	private static LookupService lookupService;
	
	/**
	 * Convert an IP address to a physical location.
	 * 
	 * @param ip IP address
	 * @return Location instance
	 */
	public static Location ipToPoint(InetAddress ip) {
		
		return ipToPoint(ip.getHostAddress());
	}
	
	/**
	 * Convert an IP address to a physical location
	 * 
	 * @param ip IP address string on dot-notation form
	 * @return Location instance
	 */
	public static Location ipToPoint(String ip) {
				
		if (lookupService == null) {
			try {
				lookupService = new LookupService("geoip/GeoIPCity.dat");
			} catch (IOException e) {
				// TODO Auto-generated catch block
				e.printStackTrace();
			}
		}
		
		return lookupService.getLocation(ip);
	}
}
