package no.ntnu.vegare.visualizer.client.utils;

import java.text.SimpleDateFormat;
import java.util.Date;

/**
 * <p>Provides access to commonly used date and time utility functions.
 * All methods are static and universally available, and should not depend
 * on any state.</p>
 * 
 * @author vegare
 *
 */
public class TimeUtils {
	
	public static final int MINUTE	= 60;
	public static final int HOUR	= 60*MINUTE;
	public static final int DAY		= 24*HOUR;
	public static final int WEEK	= 7*DAY;
	public static final int YEAR	= 365*DAY;
	
	private static SimpleDateFormat dateFormat = new SimpleDateFormat("dd.MM.yy HH:mm");
	
	/**
	 * @return Current UNIX timestamp (seconds since epoch)
	 */
	public static int getCurrentTime() {
		return (int) (System.currentTimeMillis() / 1000L);
	}
	
	/**
	 * @return Current datetime as a Date instance
	 */
	public static Date getCurrentDate() {
		return new Date();
	}
	
	/**
	 * Returns the current time, plus/minus a given number of seconds.
	 * Parameter can be negative, causing a backward movement.
	 * 
	 * @param seconds Difference from current time in seconds
	 * @return Date instance for the specified time
	 */
	public static Date getCurrentPlus(int seconds) {
		return new Date(1000L * (getCurrentTime() + seconds));
	}

	/**
	 * Convert a Date object to a UNIX timestamp
	 * 
	 * @param value Date object
	 * @return UNIX timestamp
	 */
	public static int dateToTimestamp(Date value) {
		return (int) (value.getTime() /  1000L);
	}

	/**
	 * Convert a UNIX timestamp to a Date object
	 * 
	 * @param value UNIX timestamp
	 * @return Date object
	 */
	public static String timestampToDate(Integer value) {
		
		return dateFormat.format(new Date(value*1000L));
	}
	
	/**
	 * Round a UNIX timestamp to the closest interval.
	 * Can e.g. be used to round to closest day or year.
	 * 
	 * @param timestamp UNIX timestamp
	 * @param closest Size of interval
	 * @return New UNIX timestamp
	 */
	public static int round(int timestamp, int closest) {
		return timestamp - (timestamp % closest);
	}
}
