package no.ntnu.vegare.visualizer.server.background;

import no.ntnu.vegare.visualizer.server.db.LogDatabase;
import no.ntnu.vegare.visualizer.server.utils.DataGenerator;

/**
 * The generator thread runs in the background, where it generates random
 * incidents. This is obviously for prototype purposes only.
 * 
 * Notice that the number of incidents per hour is an average, and that
 * randomness is used to avoid too frequent updates.
 * 
 * @author vegare
 *
 */
public class GeneratorThread implements Runnable {

	private final long milliSecondsPerHour = 1000*60*60;
	
	private LogDatabase database;
	private long averageSleep;
	private boolean isRunning;
	
	/**
	 * @param db Target database
	 * @param perHour Average incidents per hour
	 */
	public GeneratorThread(LogDatabase db, int perHour) {
		database = db;
		averageSleep = milliSecondsPerHour / perHour;
		isRunning = false;
	}

	public boolean isRunning() {
		return isRunning;
	}
	
	public void stop() {
		isRunning = false;
	}

	@Override
	public void run() {
		
		isRunning = true;
		
		while (isRunning) {
			
			// Generate an event
			String facility = DataGenerator.getRandomFacility();
			String ipAddress = DataGenerator.getRandomIpAddress();
			int severity = DataGenerator.getRandomSeverity();
			
			database.addEntry(severity, facility, ipAddress, "");
			
			// Sleep average +/- random
			int rand = (int) (averageSleep*Math.random() - (averageSleep/2));
			
			try {
				Thread.sleep(averageSleep + rand);
			} catch (InterruptedException e) {
				e.printStackTrace();
			}
		}
	}
}