package no.ntnu.vegare.visualizer.server.gui;

import javax.swing.BorderFactory;
import javax.swing.JFrame;

import no.ntnu.vegare.visualizer.server.db.LogDatabase;
import no.ntnu.vegare.visualizer.server.gui.panels.EventPanel;
import no.ntnu.vegare.visualizer.server.gui.panels.GeneratorPanel;
import no.ntnu.vegare.visualizer.server.gui.panels.ServerPanel;

/**
 * <p>The graphical user interface for the server. Contains three panels, one for 
 * each of the main functions of the application.</p>
 * 
 * <p>A new frame can be launched with the following code:</p>
 * 
 * <code>ServerFrame frame = new ServerFrame(db);<br />
 * frame.setVisible(true);</code>
 * 
 * @author vegare
 *
 */
public class ServerFrame extends JFrame {

	private static final long serialVersionUID = 1523732673090518576L;

	private LogDatabase db;
	
	private ServerPanel serverPanel;
	private GeneratorPanel generatorPanel;
	private EventPanel createPanel;
	
	/**
	 * Generate a new GUI frame. Should only be called once.
	 * 
	 * @param db Database instance
	 */
	public ServerFrame(LogDatabase db) {
		
		this.db = db;
				
		setTitle("LogWheels Mock Server");
		setSize(630, 440);
		setLayout(null);
		setResizable(false);
		setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
		
		initializeComponents();
	}

	/**
	 * Initialize the panels with positioning and layout.
	 * No layout manager is used, due to simplicity.
	 */
	private void initializeComponents() {
		
		serverPanel = new ServerPanel(db);
		serverPanel.setSize(300, 130);
		serverPanel.setLocation(10, 10);
		serverPanel.setBorder(BorderFactory.createCompoundBorder(
				              BorderFactory.createTitledBorder(" Server: "),
				              BorderFactory.createEmptyBorder(5,5,5,5)));
		
		generatorPanel = new GeneratorPanel(db);
		generatorPanel.setSize(300, 130);
		generatorPanel.setLocation(320, 10);
		generatorPanel.setBorder(BorderFactory.createCompoundBorder(
					            BorderFactory.createTitledBorder(" Random generation: "),
					            BorderFactory.createEmptyBorder(5,5,5,5)));
		
		createPanel = new EventPanel(db);
		createPanel.setSize(610, 270);
		createPanel.setLocation(10, 140);
		createPanel.setBorder(BorderFactory.createCompoundBorder(
				              BorderFactory.createTitledBorder(" Create event: "),
				              BorderFactory.createEmptyBorder(5,5,5,5)));
		
		add(serverPanel);
		add(generatorPanel);
		add(createPanel);
	}
}
