package no.ntnu.vegare.visualizer.server.gui.panels;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.JTextField;

import no.ntnu.vegare.visualizer.server.db.LogDatabase;
import no.ntnu.vegare.visualizer.server.utils.DataGenerator;
import no.ntnu.vegare.visualizer.server.utils.Resources;

/**
 * <p>Panel controlling generation of a user specified incident.</p> 
 * 
 * <p>Serves both as a view and a controller, for simplicity reasons. The
 * method <code>actionPerformed</code> handles clicks on the button,
 * and creates a new incident on request</p>
 * 
 * @author vegare
 *
 */
public class EventPanel extends JPanel implements ActionListener {

	private static final long serialVersionUID = -5799869175558957607L;

	private LogDatabase db;
	
	private JLabel severityLbl;
	private JComboBox severity;
	private JButton randomSeverity;
	private JLabel facilityLbl;
	private JTextField facility;
	private JButton randomFacility;
	private JLabel ipAddressLbl;
	private JTextField ipAddress;
	private JButton randomIp;
	private JLabel msgLbl;
	private JScrollPane msgScroll;
	private JTextArea message;
	private JButton createEvent;

	private final Dimension panelSize = new Dimension(280, 190);
	private final Dimension labelSize = new Dimension(250, 30);
	private final Dimension componentSize = new Dimension(200, 30);
	private final Dimension randomSize = new Dimension(30, 30);
	
	public EventPanel(LogDatabase db) {
		
		this.db = db;
		
		setLayout(new FlowLayout(FlowLayout.CENTER, 7, 5));		
		initializeComponents();
	}
	
	/**
	 * Initialize the panels with positioning and layout.
	 * A simple flowlayout is used.
	 */
	private void initializeComponents() {
		
		severityLbl = new JLabel("Severity:");
		severityLbl.setPreferredSize(labelSize);
		
		severity = new JComboBox(new String[]{"Emergency","Alert",
											  "Critical", "Error",
											  "Warning", "Notice",
											  "Debug", "Info"});
		
		severity.setPreferredSize(componentSize);
		severity.setSelectedIndex(4);
		
		randomSeverity = new JButton(Resources.getInstance().getImage("random.png"));
		randomSeverity.setPreferredSize(randomSize);
		randomSeverity.setToolTipText("Random");
		randomSeverity.addActionListener(this);
		
		facilityLbl = new JLabel("Facility:");
		facilityLbl.setPreferredSize(labelSize);
		
		facility = new JTextField("");
		facility.setPreferredSize(componentSize);
		
		randomFacility = new JButton(Resources.getInstance().getImage("random.png"));
		randomFacility.setPreferredSize(randomSize);
		randomFacility.setToolTipText("Random");
		randomFacility.addActionListener(this);
		
		ipAddressLbl = new JLabel("Source IP address:");
		ipAddressLbl.setPreferredSize(labelSize);
		
		ipAddress = new JTextField("");
		ipAddress.setPreferredSize(componentSize);
		
		randomIp = new JButton(Resources.getInstance().getImage("random.png"));
		randomIp.setPreferredSize(randomSize);
		randomIp.setToolTipText("Random");
		randomIp.addActionListener(this);
		
		msgLbl = new JLabel("Message:");
		msgLbl.setPreferredSize(labelSize);
		
		message = new JTextArea();
		
		msgScroll = new JScrollPane(message);
		msgScroll.setPreferredSize(new Dimension(250, 150));
		
		createEvent = new JButton("Create new event", Resources.getInstance().getImage("create.png"));
		createEvent.setPreferredSize(new Dimension(250, 30));
		createEvent.addActionListener(this);		
		
		JPanel leftPanel = new JPanel();
		leftPanel.setPreferredSize(new Dimension(panelSize));
		leftPanel.setLayout(new FlowLayout(FlowLayout.CENTER, 4, 0));
		
		JPanel rightPanel = new JPanel();
		rightPanel.setPreferredSize(new Dimension(panelSize));
		rightPanel.setLayout(new FlowLayout(FlowLayout.CENTER, 4, 0));
		
		leftPanel.add(severityLbl);
		leftPanel.add(severity);
		leftPanel.add(randomSeverity);
		leftPanel.add(facilityLbl);
		leftPanel.add(facility);
		leftPanel.add(randomFacility);
		leftPanel.add(ipAddressLbl);
		leftPanel.add(ipAddress);
		leftPanel.add(randomIp);
		rightPanel.add(msgLbl);
		rightPanel.add(msgScroll);
		
		add(leftPanel);
		add(rightPanel);
		add(createEvent);
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		
		if (e.getSource() == createEvent)
			db.addEntry(severity.getSelectedIndex(), facility.getText(),
						ipAddress.getText(), message.getText());
		else if (e.getSource() == randomSeverity)
			severity.setSelectedIndex(DataGenerator.getRandomSeverity());
		else if (e.getSource() == randomFacility)
			facility.setText(DataGenerator.getRandomFacility());
		else if (e.getSource() == randomIp)
			ipAddress.setText(DataGenerator.getRandomIpAddress());
	}
}
