package no.ntnu.vegare.visualizer.server.gui.panels;

import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JSpinner;
import javax.swing.SpinnerNumberModel;

import no.ntnu.vegare.visualizer.server.background.ThreadPool;
import no.ntnu.vegare.visualizer.server.db.LogDatabase;
import no.ntnu.vegare.visualizer.server.utils.Resources;

/**
 * <p>Panel controlling the incident generator.</p>
 * 
 * <p>Accepts a number representing average incidents per hour, and launches a
 * <code>GeneratorThread</code> generating incidents.</p>
 * 
 * <p>Serves both as a view and a controller, for simplicity reasons. The
 * method <code>actionPerformed</code> handles clicks on the two buttons,
 * and starts or stops the generator through the ThreadPool class.</p>
 * 
 * @see DataGenerator
 * @see GeneratorThread
 * @author vegare
 *
 */
public class GeneratorPanel extends JPanel implements ActionListener {

	private static final long serialVersionUID = 7203831742068843292L;

	private LogDatabase db;
	
	private JLabel generate;
	private JLabel perHourLbl;
	private JSpinner perHour;
	private JButton startGeneration;
	private JButton stopGeneration;
	
	public GeneratorPanel(LogDatabase db) {
		
		this.db = db;
		setLayout(new FlowLayout(FlowLayout.CENTER, 7, 10));		
		initializeComponents();
	}
	
	/**
	 * Initialize the panels with positioning and layout.
	 * A simple flowlayout is used.
	 */
	private void initializeComponents() {
		
		generate = new JLabel("Generate");
		
		perHour = new JSpinner(new SpinnerNumberModel(20, 0, 120, 1));
		perHour.setEditor(new JSpinner.NumberEditor(perHour, "####"));
		
		perHourLbl = new JLabel("incidents per hour");
		
		startGeneration = new JButton("Start", Resources.getInstance().getImage("generate.png"));
		startGeneration.setPreferredSize(new Dimension(100, 30));
		startGeneration.addActionListener(this);
		
		stopGeneration = new JButton("Stop", Resources.getInstance().getImage("stop.png"));
		stopGeneration.setPreferredSize(new Dimension(100, 30));
		stopGeneration.setEnabled(false);
		stopGeneration.addActionListener(this);
		
		add(generate);
		add(perHour);
		add(perHourLbl);
		add(startGeneration);
		add(stopGeneration);
	}

	@Override
	public void actionPerformed(ActionEvent e) {
		
		if (e.getSource() == startGeneration) {
			
			String msg = ThreadPool.getInstance().startGenerator(db, (Integer) perHour.getValue());
			
			if ("OK".equals(msg)) {				
				startGeneration.setEnabled(false);
				stopGeneration.setEnabled(true);				
			}
			
		} else if (e.getSource() == stopGeneration) {
			
			String msg = ThreadPool.getInstance().stopGenerator();
			
			if ("OK".equals(msg)) {				
				startGeneration.setEnabled(true);
				stopGeneration.setEnabled(false);				
			}
		}
	}
}
