package no.ntnu.vegare.visualizer.server.utils;

import java.util.HashMap;

import javax.swing.ImageIcon;

/**
 * <p>Thread safe singleton implementation by Bill Pugh:
 * <a href="http://en.wikipedia.org/wiki/Singleton_pattern">
 * http://en.wikipedia.org/wiki/Singleton_pattern</a></p>
 * 
 * <p>Provides access to static resources related to the project.
 * Allows preloading of large images by using the method
 * <code>preloadResources()</code>. Keeps all loaded resources in memory.</p>
 * 
 * @author vegare
 *
 */
public class Resources {

	private HashMap<String, ImageIcon> images;
	
	// Private constructor prevents instantiation from other classes
	private Resources() {
		
		images = new HashMap<String, ImageIcon>(20);
	}
	 
	/**
	 * SingletonHolder is loaded on the first execution of Singleton.getInstance() 
	 * or the first access to SingletonHolder.INSTANCE, not before.
	 */
	private static class SingletonHolder { 
		public static final Resources INSTANCE = new Resources();
	}
	 
	public static Resources getInstance() {
		return SingletonHolder.INSTANCE;
	}
	
	/**
	 * Preload big images
	 */
	public void preloadResources() {
		// None
	}
	
	/**
	 * Return an imageicon from memory if cached, otherwise load it from disk.
	 * 
	 * @see ImageIcon
	 * @param name Path to file located in the img/ folder
	 * @return ImageIcon representation of the image
	 */
	public ImageIcon getImage(String name)
	{		
		if (images.containsKey(name))
			return images.get(name);
		
		ImageIcon img = new ImageIcon("img/" + name);
		images.put(name, img);
		
		return img;
	}
}
